import { jsx as _jsx } from "react/jsx-runtime";
import { createEventTarget } from "dom-event-testing-library";
import * as React from "react";
import * as ReactDOM from "react-dom";
import * as ReactDOMServer from "react-dom/server";
import { act } from "react-dom/test-utils";
import createEventHandle from "..";
function createRoot(rootNode) {
  return {
    render(element) {
      ReactDOM.render(element, rootNode);
    }
  };
}
describe("create-event-handle", function() {
  var root, rootNode;
  beforeEach(function() {
    rootNode = document.createElement("div"), document.body.appendChild(rootNode), root = createRoot(rootNode);
  }), afterEach(function() {
    root.render(null), document.body.removeChild(rootNode), rootNode = null, root = null;
  }), test("can render correctly using ReactDOMServer", function() {
    var listener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click");
    function Component() {
      return React.useEffect(function() {
        return addClickListener(targetRef.current, listener);
      }), /* @__PURE__ */ _jsx("div", {
        ref: targetRef
      });
    }
    var output = ReactDOMServer.renderToString(/* @__PURE__ */ _jsx(Component, {}));
    expect(output).toBe('<div data-reactroot=""></div>');
  }), describe("createEventTarget()", function() {
    test("event dispatched on target", function() {
      var listener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click");
      function Component() {
        return React.useEffect(function() {
          return addClickListener(targetRef.current, listener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var target = createEventTarget(targetRef.current);
      act(function() {
        target.click();
      }), expect(listener).toBeCalledTimes(1);
    }), test("event dispatched on parent", function() {
      var listener = jest.fn(), listenerCapture = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), parentRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click"), addClickCaptureListener = createEventHandle("click", {
        capture: !0
      });
      function Component() {
        return React.useEffect(function() {
          var removeClickListener = addClickListener(targetRef.current, listener), removeClickCaptureListener = addClickCaptureListener(targetRef.current, listenerCapture);
          return function() {
            removeClickListener(), removeClickCaptureListener();
          };
        }), /* @__PURE__ */ _jsx("div", {
          ref: parentRef,
          children: /* @__PURE__ */ _jsx("div", {
            ref: targetRef
          })
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var parent = createEventTarget(parentRef.current);
      act(function() {
        parent.click();
      }), expect(listener).toBeCalledTimes(0), expect(listenerCapture).toBeCalledTimes(0);
    }), test("event dispatched on child", function() {
      var log = [], listener = jest.fn(function() {
        log.push("bubble");
      }), listenerCapture = jest.fn(function() {
        log.push("capture");
      }), targetRef = /* @__PURE__ */ React.createRef(), childRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click"), addClickCaptureListener = createEventHandle("click", {
        capture: !0
      });
      function Component() {
        return React.useEffect(function() {
          var removeClickListener = addClickListener(targetRef.current, listener), removeClickCaptureListener = addClickCaptureListener(targetRef.current, listenerCapture);
          return function() {
            removeClickListener(), removeClickCaptureListener();
          };
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef,
          children: /* @__PURE__ */ _jsx("div", {
            ref: childRef
          })
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var child = createEventTarget(childRef.current);
      act(function() {
        child.click();
      }), expect(listenerCapture).toBeCalledTimes(1), expect(listener).toBeCalledTimes(1), expect(log).toEqual([
        "capture",
        "bubble"
      ]);
    }), test("event dispatched on text node", function() {
      var listener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), childRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click");
      function Component() {
        return React.useEffect(function() {
          return addClickListener(targetRef.current, listener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef,
          children: /* @__PURE__ */ _jsx("div", {
            ref: childRef,
            children: "text"
          })
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var text = createEventTarget(childRef.current.firstChild);
      act(function() {
        text.click();
      }), expect(listener).toBeCalledTimes(1);
    }), test("listener can be attached to document", function() {
      var listener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click");
      function Component(param) {
        var { target: target2 } = param;
        return React.useEffect(function() {
          return addClickListener(target2, listener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {
          target: document
        }));
      });
      var target = createEventTarget(targetRef.current);
      act(function() {
        target.click();
      }), expect(listener).toBeCalledTimes(1);
    }), test("listener can be attached to window ", function() {
      var listener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click");
      function Component(param) {
        var { target: target2 } = param;
        return React.useEffect(function() {
          return addClickListener(target2, listener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {
          target: window
        }));
      });
      var target = createEventTarget(targetRef.current);
      act(function() {
        target.click();
      }), expect(listener).toBeCalledTimes(1);
    }), test("custom event dispatched on target", function() {
      var listener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), addMagicEventListener = createEventHandle("magic-event");
      function Component() {
        return React.useEffect(function() {
          return addMagicEventListener(targetRef.current, listener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      }), act(function() {
        var event = new CustomEvent("magic-event", {
          bubbles: !0
        });
        targetRef.current.dispatchEvent(event);
      }), expect(listener).toBeCalledTimes(1);
    }), test("listeners can be set on multiple targets simultaneously", function() {
      var log = [], targetRef = /* @__PURE__ */ React.createRef(), parentRef = /* @__PURE__ */ React.createRef(), childRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click"), addClickCaptureListener = createEventHandle("click", {
        capture: !0
      }), listener = jest.fn(function(e) {
        log.push([
          "bubble",
          e.currentTarget.id
        ]);
      }), listenerCapture = jest.fn(function(e) {
        log.push([
          "capture",
          e.currentTarget.id
        ]);
      });
      function Component() {
        return React.useEffect(function() {
          addClickListener(targetRef.current, listener), addClickListener(parentRef.current, listener), addClickCaptureListener(targetRef.current, listenerCapture), addClickCaptureListener(parentRef.current, listenerCapture);
        }), /* @__PURE__ */ _jsx("div", {
          id: "parent",
          ref: parentRef,
          children: /* @__PURE__ */ _jsx("div", {
            id: "target",
            ref: targetRef,
            children: /* @__PURE__ */ _jsx("div", {
              ref: childRef
            })
          })
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var child = createEventTarget(childRef.current);
      act(function() {
        child.click();
      }), expect(listenerCapture).toBeCalledTimes(2), expect(listener).toBeCalledTimes(2), expect(log).toEqual([
        [
          "capture",
          "parent"
        ],
        [
          "capture",
          "target"
        ],
        [
          "bubble",
          "target"
        ],
        [
          "bubble",
          "parent"
        ]
      ]);
    }), test("listeners are specific to each event handle", function() {
      var log = [], targetRef = /* @__PURE__ */ React.createRef(), childRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click"), addClickAltListener = createEventHandle("click"), addClickCaptureListener = createEventHandle("click", {
        capture: !0
      }), addClickCaptureAltListener = createEventHandle("click", {
        capture: !0
      }), listener = jest.fn(function(e) {
        log.push([
          "bubble",
          "target"
        ]);
      }), listenerAlt = jest.fn(function(e) {
        log.push([
          "bubble",
          "target-alt"
        ]);
      }), listenerCapture = jest.fn(function(e) {
        log.push([
          "capture",
          "target"
        ]);
      }), listenerCaptureAlt = jest.fn(function(e) {
        log.push([
          "capture",
          "target-alt"
        ]);
      });
      function Component() {
        return React.useEffect(function() {
          addClickListener(targetRef.current, listener), addClickAltListener(targetRef.current, listenerAlt), addClickCaptureListener(targetRef.current, listenerCapture), addClickCaptureAltListener(targetRef.current, listenerCaptureAlt);
        }), /* @__PURE__ */ _jsx("div", {
          id: "target",
          ref: targetRef,
          children: /* @__PURE__ */ _jsx("div", {
            ref: childRef
          })
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var child = createEventTarget(childRef.current);
      act(function() {
        child.click();
      }), expect(listenerCapture).toBeCalledTimes(1), expect(listenerCaptureAlt).toBeCalledTimes(1), expect(listener).toBeCalledTimes(1), expect(listenerAlt).toBeCalledTimes(1), expect(log).toEqual([
        [
          "capture",
          "target"
        ],
        [
          "capture",
          "target-alt"
        ],
        [
          "bubble",
          "target"
        ],
        [
          "bubble",
          "target-alt"
        ]
      ]);
    });
  }), describe("stopPropagation and stopImmediatePropagation", function() {
    test("stopPropagation works as expected", function() {
      var childListener = jest.fn(function(e) {
        e.stopPropagation();
      }), targetListener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), childRef = /* @__PURE__ */ React.createRef(), addClickListener = createEventHandle("click");
      function Component() {
        return React.useEffect(function() {
          addClickListener(childRef.current, childListener), addClickListener(targetRef.current, targetListener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef,
          children: /* @__PURE__ */ _jsx("div", {
            ref: childRef
          })
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var child = createEventTarget(childRef.current);
      act(function() {
        child.click();
      }), expect(childListener).toBeCalledTimes(1), expect(targetListener).toBeCalledTimes(0);
    }), test("stopImmediatePropagation works as expected", function() {
      var firstListener = jest.fn(function(e) {
        e.stopImmediatePropagation();
      }), secondListener = jest.fn(), targetRef = /* @__PURE__ */ React.createRef(), addFirstClickListener = createEventHandle("click"), addSecondClickListener = createEventHandle("click");
      function Component() {
        return React.useEffect(function() {
          addFirstClickListener(targetRef.current, firstListener), addSecondClickListener(targetRef.current, secondListener);
        }), /* @__PURE__ */ _jsx("div", {
          ref: targetRef
        });
      }
      act(function() {
        root.render(/* @__PURE__ */ _jsx(Component, {}));
      });
      var target = createEventTarget(targetRef.current);
      act(function() {
        target.click();
      }), expect(firstListener).toBeCalledTimes(1), expect(secondListener).toBeCalledTimes(0);
    });
  });
});
//# sourceMappingURL=index-test.js.map
